@@ -55,15 +55,15 @@ public:
         Thumbnail  = Qt::UserRole + 3
     };
 
-    DirModel(QObject* parent=0);
-    virtual ~DirModel();
+    explicit DirModel(QObject* parent=nullptr);
+    ~DirModel() override;
 
     QHash<int, QByteArray> roleNames() const override;
 
     void setUrl(const QString& url);
     QString url() const;
 
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role) const override;
     int count() const {return rowCount();}
 
     Q_INVOKABLE int indexForUrl(const QString &url) const;
@@ -88,7 +88,7 @@ private:
     QStringList m_mimeTypes;
 
     //previews
-    QTimer *m_previewTimer;
+    QTimer *m_previewTimer = nullptr;
     QHash<QUrl, QPersistentModelIndex> m_filesToPreview;
     QSize m_screenshotSize;
     QHash<QUrl, QPersistentModelIndex> m_previewJobs;
