@@ -24,7 +24,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include <QtCore/QSet>
+#include <QSet>
 #include <QUrl>
 
 class QWidget;
